A tibble containing the stations information. Further details available here stations.
Arguments
byStation
Logic value (T or F). If TRUE the dataset is organized by station (one row for each measurement station).
If FALSE the dataset is organized by sampling point. Each station have multiple sampling points.
complete
Logic value (T or F). If TRUE, the dataset contains all the variables given by the EEA.
If FALSE the dataset contains only a few variables, the most importants. For further details about the variables, see stations.