- data
an object of class EEAaq_taggr_df or EEAaq_taggr_df_sfc, which is the
output of the EEAaq_time_aggregate function.
- pollutant
vector containing the pollutant for which to build the map. It must be one of the pollutants
contained in data.
- aggr_fun
character containing the aggregation function to use for computing the interpolation. It must
be one of the statistics contained in data.
- distinct
logic value (T or F). If TRUE, each map generated is printed and saved in distinct pages
(for instance if data has a monthly frequency in a yearly time window, 12 distinct plots are generated).
If FALSE (the default), the maps are printed in a single page.
- gradient
logic value (T or F). If TRUE (the default) the maps generated are colored with a
continuous color scale. If FALSE, the color scale is discrete.
- idp
numeric value that specify the inverse distance weighting power. For further information see
idw.
- nmax
numeric value; specify the number of nearest observations that should be
used for the inverse distance weighting computing, where nearest is defined in terms of the
space of the spatial locations. By default, all observations are used. For further information see
idw
- maxdist
numeric value; only observations within a distance of maxdist from the prediction location
are used for the idw computation. By default, all observations are used.
If combined with nmax, both criteria apply.
- NUTS_filler
character containing the NUTS level or LAU for which to aggregate the idw computing,
in order to obtain a uniform coloring inside each area at the specified level.
Recall that the NUTS classification (Nomenclature of territorial units for statistics) is a hierarchical system for dividing up the economic territory of the EU and the UK.
The levels are defined as follows:
NUTS 0: the whole country
NUTS 1: major socio-economic regions
NUTS 2: basic regions for the application of regional policies
NUTS 3: small regions for specific diagnoses
LAU: municipality
For instance if NUTS_filler = "LAU", each municipality is filled by the mean value of the pollutant
concentration, computed by the idw, of each pixel inside the respective municipality). Allowed values are
'NUTS0', 'NUTS1', 'NUTS2', 'NUTS3', and 'LAU'.
- NUTS_extborder
character containing the NUTS level or LAU for which draw external boundaries.
Admissible values are 'NUTS0', 'NUTS1', 'NUTS2', 'NUTS3', 'LAU'.
- NUTS_intborder
character containing the NUTS level or LAU for which draw internal boundaries.
Admissible values are 'NUTS0', 'NUTS1', 'NUTS2', 'NUTS3', 'LAU'.
- dynamic
logic value (T or F). If TRUE the function creates a Leaflet map widget using
htmlwidgets (for further information see leaflet). If FALSE (the default)
the maps generated are static.
- tile
character representing the name of the provider tile. To see the full list of the providers, run
providers. For further information see addProviderTiles.
- filepath
a character string giving the file path.
- width, height
the width and the height of the plot, expressed in pixels (by default width = 1280, height = 720).
This parameters are available only for save 'jpeg', 'png' and 'gif'.
For further information see png or jpeg.
- res
the nominal resolution in ppi which will be recorded in the bitmap file, if a positive integer
(by default res = 144). This parameter is available only for save 'jpeg', 'png'.
For further information see png or jpeg.
- delay
numeric value specifying the time to show each image in seconds, when save = "gif".
- save
character representing in which extension to save the map. Allowed values are 'jpeg', 'png', 'pdf'
(if dynamic = FALSE), 'gif' (if dynamic = FALSE & distinct = TRUE), 'html' (if dynamic = TRUE).
- verbose
logic value (T or F). If TRUE (the default) information about the function progress are printed.
If FALSE no message is printed.