Learn R Programming

EEAaq (version 1.0.3)

EEAaq_summary: Generate an EEAaq_df data summary

Description

This function, applied to an EEAaq_df or EEAaq_df_sfc class object, produces a list of data frames, containing relevant information about the data, such as descriptive statistics, missing values statistics, gap length and correlation.

Usage

EEAaq_summary(data = NULL, verbose = TRUE)

Value

The function EEAaq_summary computes and return a list of summary statistics of the dataset given in data. In particular the elements of the list are:

  • Summary global missing count, missing rate, negative count, minimum, maximum, mean and standard deviation, organized by pollutant.

  • Summary_byStat list of data frames, one for each different station, containing the descriptive statistics (missing count, missing rate, negative count, minimum, maximum, mean and standard deviation), organized by station.

  • gap_length one data frame for each pollutant, containing the gap length organized by station.

  • Corr_Matrix if data contains more than one pollutant, the correlation matrix between pollutans is provided, organised by station.

Arguments

data

an EEAaq_df or EEAaq_df_sfc class object, which is the output of the EEAaq_get_data function.

verbose

logic value (T or F). If TRUE (the default) messages about the function progress are printed. If FALSE no message is printed.

Examples

Run this code
# \donttest{
### Download PM10 data for the province (NUTS-3) of Milano (Italy)
##from January 1st to January 31st, 2023
IDstations <- EEAaq_get_stations(byStation = TRUE, complete = FALSE)
`%>%` <- dplyr::`%>%`
IDstations <- IDstations %>%
                dplyr::filter(NUTS3 %in% c("Milano")) %>%
                dplyr::pull(AirQualityStationEoICode) %>%
                unique()
data <- EEAaq_get_data(IDstations = IDstations, pollutants = "PM10",
                       from = "2023-01-01", to = "2023-01-31", verbose = TRUE)

### Compute summary statistics
EEAaq_summary(data)
# }

Run the code above in your browser using DataLab