my_summarise: Aggregate data based on a specific statistic
Description
Given data and the aggregation function desired, this function compute a time aggregation of the data.
Usage
my_summarise(data, fun_aggr)
Value
A tibble with the required aggregation.
Arguments
- data
An EEAaq_df or EEAaq_df_sfc class object, which is the output of the
EEAaq_get_data function.
- fun_aggr
Vector character containing the aggregation function for which to time aggregate.